@@ -12,19 +12,30 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+AioAWS Batch-DB
+===============
+
+"""
+
 import abc
 import asyncio
 import json
+from collections import Counter
+from collections import defaultdict
 from dataclasses import dataclass
 from pathlib import Path
+from typing import AsyncIterator
 from typing import Dict
 from typing import List
 from typing import Optional
 from typing import Set
+from typing import Tuple
 
 import tinydb
 
 from aio_aws.aws_batch_models import AWSBatchJob
+from aio_aws.aws_batch_models import AWSBatchJobStates
 from aio_aws.logger import get_logger
 from aio_aws.uuid_utils import valid_uuid4
 
@@ -37,10 +48,60 @@ class AioAWSBatchDB(abc.ABC):
     Abstract Base Class for AWS Batch job databases
     """
 
+    @abc.abstractmethod
+    async def all_jobs(self) -> List[AWSBatchJob]:
+        """
+        Collect all jobs.
+
+        Warning: this could exceed memory, try to use
+        the :py:meth:`gen_all_jobs` wherever possible.
+        """
+        pass
+
+    @abc.abstractmethod
+    async def gen_all_jobs(self) -> AsyncIterator[AWSBatchJob]:
+        """
+        Generate all jobs.
+        """
+        yield
+
     @abc.abstractmethod
     async def all_job_ids(self) -> Set[str]:
         """
-        Find all jobId.
+        Collect all jobIds.
+        """
+        pass
+
+    @abc.abstractmethod
+    async def gen_job_ids(self) -> AsyncIterator[str]:
+        """
+        Generate all jobIds.
+        """
+        yield
+
+    @abc.abstractmethod
+    async def count_by_job_status(self) -> Counter:
+        """
+        Count all jobs by jobStatus
+
+        :return: a Counter of jobs by job status (could contain multiple
+            entries for the same jobName, if it is run more than once)
+        """
+        pass
+
+    @abc.abstractmethod
+    async def group_by_job_status(self) -> Dict[str, List[Tuple[str, str, str]]]:
+        """
+        Group all jobId by jobStatus
+
+        :return: a dictionary of job info by job status (could contain multiple
+            entries with the same jobName if it is run multiple times);
+            the dictionary values contain a list of job information tuples, e.g.
+
+            .. code-block::
+
+                { status: [ (job.job_id, job.job_name, job.status), ] }
+
         """
         pass
 
@@ -179,7 +240,7 @@ class AioAWSBatchDB(abc.ABC):
 @dataclass
 class AioAWSBatchRedisDB(AioAWSBatchDB):
     """
-    AWS Batch job databases
+    AWS Batch job databases - aioredis implementation
 
     The jobs and logs are kept in separate DBs so
     that performance on the jobs_db is not compromised
@@ -188,7 +249,7 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
 
     """
 
-    redis_url: str = "redis://localhost"
+    redis_url: str = "redis://127.0.0.1:6379"
 
     # TODO: use files to dump redis-db?
     # #: a file used for dumping jobs-db
@@ -202,60 +263,235 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         # that performance on the jobs_db is not compromised
         # by too much data from job logs.
 
-        # lazy load this an optional dependency
-        import aioredis
-
-        # Redis client bound to pool of connections (auto-reconnecting).
-        self.jobs_db = aioredis.from_url(
-            self.redis_url,
-            db=2,
-            encoding="utf-8",
-            decode_responses=True,
-            max_connections=10,
-        )
-        self.logs_db = aioredis.from_url(
-            self.redis_url,
-            db=4,
-            encoding="utf-8",
-            decode_responses=True,
-            max_connections=10,
-        )
-
         # Lazy init for any asyncio instances
         self._db_sem = None
 
+    @property
+    async def jobs_db(self):
+        # lazy load this optional dependency
+        import aioredis
+
+        # need to instantiate redis-connection on-demand to avoid
+        # Future <Future pending> attached to a different loop
+        # TODO: lean how to optimize connections to auto-close them
+
+        async with self.db_semaphore:
+            return aioredis.from_url(
+                self.redis_url,
+                db=2,
+                encoding="utf-8",
+                decode_responses=True,
+                max_connections=1,
+            )
+
+    @property
+    async def logs_db(self):
+        # lazy load this optional dependency
+        import aioredis
+
+        # need to instantiate redis-connection on-demand to avoid
+        # Future <Future pending> attached to a different loop
+        async with self.db_semaphore:
+            return aioredis.from_url(
+                self.redis_url,
+                db=4,
+                encoding="utf-8",
+                decode_responses=True,
+                max_connections=1,
+            )
+
     @property
     def db_semaphore(self) -> asyncio.Semaphore:
         """A semaphore to limit requests to the db"""
         if self._db_sem is None:
-            self._db_sem = asyncio.Semaphore(10)
+            self._db_sem = asyncio.Semaphore(100)
         return self._db_sem
 
+    @classmethod
+    async def _is_db_alive(cls, db) -> bool:
+        try:
+            assert await db.ping() is True
+            return True
+        except AssertionError:
+            return False
+
+    @property
+    async def jobs_db_alive(self) -> "Redis":
+        for tries in range(5):
+            jobs_db = await self.jobs_db
+            db_alive = await self._is_db_alive(jobs_db)
+            if db_alive:
+                return jobs_db
+            else:
+                await asyncio.sleep(0.0001, 0.005)
+
+    @property
+    async def logs_db_alive(self) -> "Redis":
+        for tries in range(5):
+            logs_db = await self.logs_db
+            db_alive = await self._is_db_alive(logs_db)
+            if db_alive:
+                return logs_db
+            else:
+                await asyncio.sleep(0.0001, 0.005)
+
     @property
     async def db_alive(self) -> bool:
         try:
-            assert await self.jobs_db.ping() is True
-            assert await self.logs_db.ping() is True
+            assert await self.jobs_db_alive
+            assert await self.logs_db_alive
+            return True
         except AssertionError:
             return False
-        return True
 
     @property
     async def db_info(self) -> Dict:
+        jobs_db = await self.jobs_db_alive
+        logs_db = await self.logs_db_alive
         info = {
-            "jobs": await self.jobs_db.info(),
-            "logs": await self.logs_db.info(),
+            "jobs": await jobs_db.info(),
+            "logs": await logs_db.info(),
         }
         LOGGER.debug("Using batch-jobs redis-db: %s", info)
         return info
 
-    async def db_close(self):
-        await self.jobs_db.close()
-        await self.logs_db.close()
+    # async def db_close(self):
+    #     await self.jobs_db.close()
+    #     await self.logs_db.close()
 
     async def db_save(self):
-        assert await self.jobs_db.bgsave() is True
-        assert await self.logs_db.bgsave() is True
+        jobs_db = await self.jobs_db_alive
+        logs_db = await self.logs_db_alive
+        assert await jobs_db.bgsave() is True
+        assert await logs_db.bgsave() is True
+
+    @classmethod
+    async def _find_by_job_id(cls, job_id: str, jobs_db: "Redis") -> Dict:
+        """
+        Private method to find any job matching the jobId
+
+        :param job_id: a batch jobName
+        :param jobs_db: an async Redis
+        :return: the job data or None
+        """
+        if job_id:
+            job_json = await jobs_db.get(job_id)
+            if job_json:
+                return json.loads(job_json)
+
+    @classmethod
+    async def _find_by_job_name(cls, job_name: str, jobs_db: "Redis") -> List[Dict]:
+        """
+        Private method to find any jobs matching the jobName
+
+        :param job_name: a batch jobName
+        :param jobs_db: an async Redis
+        :return: a list of dictionaries containing job data
+        """
+        jobs = []
+        if job_name:
+            job_ids = await jobs_db.get(job_name)
+            if job_ids:
+                # This should be a list of batch job-ids for a job name
+                job_ids = set(json.loads(job_ids))
+                for job_id in job_ids:
+                    job_json = await jobs_db.get(job_id)
+                    if job_json:
+                        job_dict = json.loads(job_json)
+                        jobs.append(job_dict)
+        return jobs
+
+    async def all_job_ids(self) -> Set[str]:
+        """
+        Collect all jobIds.
+        """
+        job_ids = set()
+        async for key in self.gen_job_ids():
+            job_ids.add(key)
+        return job_ids
+
+    async def gen_job_ids(self) -> AsyncIterator[str]:
+        """
+        Generate all jobIds.
+        """
+        jobs_db = await self.jobs_db_alive
+        async for key in jobs_db.scan_iter():
+            if valid_uuid4(key):
+                yield key
+
+    async def all_jobs(self) -> List[AWSBatchJob]:
+        """
+        Collect all jobs.
+
+        Warning: this could exceed memory, try to use
+        the :py:meth:`gen_all_jobs` wherever possible.
+        """
+        jobs = []
+        async for j in self.gen_all_jobs():
+            jobs.append(j)
+        return jobs
+
+    async def gen_all_jobs(self) -> AsyncIterator[AWSBatchJob]:
+        """
+        Generate all jobs.
+        """
+        jobs_db = await self.jobs_db_alive
+        async for key in jobs_db.scan_iter():
+            if valid_uuid4(key):
+                # The key is a jobId that conforms to UUID
+                job_json = await jobs_db.get(key)
+                if job_json:
+                    job_dict = json.loads(job_json)
+                    yield AWSBatchJob(**job_dict)
+
+    async def count_by_job_status(self) -> Counter:
+        """
+        Count all jobs by jobStatus
+
+        :return: a Counter of jobs by job status (could contain multiple
+            entries for the same jobName, if it is run more than once)
+        """
+        counter = Counter()
+        for job_status in AWSBatchJobStates:
+            counter[job_status.name] = 0
+        jobs_db = await self.jobs_db_alive
+        async for key in jobs_db.scan_iter():
+            if valid_uuid4(key):
+                # The key is a jobId that conforms to UUID
+                job_json = await jobs_db.get(key)
+                if job_json:
+                    job_dict = json.loads(job_json)
+                    job = AWSBatchJob(**job_dict)
+                    counter[job.status] += 1
+        return counter
+
+    async def group_by_job_status(self) -> Dict[str, List[Tuple[str, str, str]]]:
+        """
+        Group all jobId by jobStatus
+
+        :return: a dictionary of job info by job status (could contain multiple
+            entries with the same jobName if it is run multiple times);
+            the dictionary values contain a list of job information tuples, e.g.
+
+            .. code-block::
+
+                { status: [ (job.job_id, job.job_name, job.status), ] }
+
+        """
+        groups = defaultdict(list)
+        for job_status in AWSBatchJobStates:
+            groups[job_status.name] = []
+        jobs_db = await self.jobs_db_alive
+        async for key in jobs_db.scan_iter():
+            if valid_uuid4(key):
+                # The key is a jobId that conforms to UUID
+                job_json = await jobs_db.get(key)
+                if job_json:
+                    job_dict = json.loads(job_json)
+                    job = AWSBatchJob(**job_dict)
+                    job_info = (job.job_id, job.job_name, job.status)
+                    groups[job.status].append(job_info)
+        return groups
 
     async def find_by_job_id(self, job_id: str) -> Optional[Dict]:
         """
@@ -265,9 +501,8 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         :return: the job data or None
         """
         if job_id:
-            job_json = await self.jobs_db.get(job_id)
-            if job_json:
-                return json.loads(job_json)
+            jobs_db = await self.jobs_db_alive
+            return await self._find_by_job_id(job_id=job_id, jobs_db=jobs_db)
 
     async def find_by_job_name(self, job_name: str) -> List[Dict]:
         """
@@ -276,17 +511,9 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         :param job_name: a batch jobName
         :return: a list of dictionaries containing job data
         """
-        jobs = []
         if job_name:
-            job_ids = await self.jobs_db.get(job_name)
-            if job_ids:
-                # This should be a list of batch job-ids for a job name
-                job_ids = set(json.loads(job_ids))
-                for job_id in job_ids:
-                    job_dict = await self.find_by_job_id(job_id)
-                    if job_dict:
-                        jobs.append(job_dict)
-        return jobs
+            jobs_db = await self.jobs_db_alive
+            return await self._find_by_job_name(job_name=job_name, jobs_db=jobs_db)
 
     async def find_latest_job_name(self, job_name: str) -> Optional[AWSBatchJob]:
         """
@@ -299,7 +526,7 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         jobs_saved = await self.find_by_job_name(job_name)
         if jobs_saved:
             db_jobs = [AWSBatchJob(**job_dict) for job_dict in jobs_saved]
-            db_jobs = sorted(db_jobs, key=lambda j: j.created)
+            db_jobs = sorted(db_jobs, key=lambda j: j.created or j.submitted)
             db_job = db_jobs[-1]
             return db_job
 
@@ -316,10 +543,11 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
             assert status in AWSBatchJob.STATES
 
         jobs = []
-        async for key in self.jobs_db.scan_iter():
+        jobs_db = await self.jobs_db_alive
+        async for key in jobs_db.scan_iter():
             if valid_uuid4(key):
                 # The key is a jobId that conforms to UUID
-                job_json = await self.jobs_db.get(key)
+                job_json = await jobs_db.get(key)
                 if job_json:
                     job_dict = json.loads(job_json)
                     job = AWSBatchJob(**job_dict)
@@ -334,25 +562,27 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         :param job_id: a batch jobId
         :return: a deleted document
         """
+        # TODO: use a transaction
         if job_id:
-            job_dict = await self.find_by_job_id(job_id)
+            jobs_db = await self.jobs_db_alive
+            job_dict = await self._find_by_job_id(job_id=job_id, jobs_db=jobs_db)
             if job_dict:
-                # TODO: use a transaction
                 # First try to remove this job-id from the job-name
                 job_name = job_dict["job_name"]
-                job_ids = await self.jobs_db.get(job_name)
-                if job_ids:
+                job_name_doc = await jobs_db.get(job_name)
+                if job_name_doc:
                     # This should be a list of batch job-ids for a job name
-                    job_ids = set(json.loads(job_ids))
+                    job_ids: List = json.loads(job_name_doc)
                     if job_id in job_ids:
                         job_ids.remove(job_id)
-                        if job_ids:
-                            await self.jobs_db.set(job_name, job_ids)
-                        else:
-                            # Don't save an empty set, delete the job-name entirely
-                            await self.jobs_db.delete(job_name)
+                    if job_ids:
+                        job_name_doc = json.dumps(list(job_ids))
+                        await jobs_db.set(job_name, job_name_doc)
+                    else:
+                        # Don't save an empty set, delete the job-name entirely
+                        await jobs_db.delete(job_name)
 
-                await self.jobs_db.delete(job_id)
+                await jobs_db.delete(job_id)
                 return job_dict
 
     async def remove_by_job_name(self, job_name: str) -> Set[str]:
@@ -362,16 +592,14 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         :param job_name: a batch jobName
         :return: a set of deleted job-ids
         """
-        job_ids = set()
         if job_name:
-            job_ids = await self.jobs_db.get(job_name)
-            if not job_ids:
-                job_ids = set()
-            else:
-                job_ids = set(json.loads(job_ids))
-            await self.jobs_db.delete(*job_ids)
-            await self.jobs_db.delete(job_name)
-        return job_ids
+            jobs_db = await self.jobs_db_alive
+            job_name_doc = await jobs_db.get(job_name)
+            if job_name_doc:
+                job_ids = set(json.loads(job_name_doc))
+                await jobs_db.delete(*job_ids)
+                await jobs_db.delete(job_name)
+                return job_ids
 
     async def save_job(self, job: AWSBatchJob) -> Optional[str]:
         """
@@ -385,26 +613,39 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
             return
 
         # TODO: use a transaction
+
+        jobs_db = await self.jobs_db_alive
         job_json = json.dumps(job.db_data)
-        response = await self.jobs_db.set(job.job_id, job_json)
-        LOGGER.debug(response)
-        if not response:
-            msg = f"FAIL to save_job with job_id: {job.job_id}"
-            LOGGER.error(msg)
-            raise RuntimeError(msg)
 
-        # Update the job-id set for the job-name
-        job_ids = await self.jobs_db.get(job.job_name)
-        if not job_ids:
-            job_ids = set()
-        else:
-            job_ids = set(json.loads(job_ids))
-        if job.job_id not in job_ids:
-            job_ids.add(job.job_id)
-            job_ids = json.dumps(list(job_ids))
-            await self.jobs_db.set(job.job_name, job_ids)
+        for tries in range(3):
+            try:
+                response = await jobs_db.set(job.job_id, job_json)
+                LOGGER.debug(response)
+                if response:
+                    LOGGER.info(
+                        "AWS batch-db (%s:%s) saved status: %s",
+                        job.job_name,
+                        job.job_id,
+                        job.status,
+                    )
 
-        return job.job_id
+                # Update the job-id set for the job-name
+                job_ids = []
+                job_name_doc = await jobs_db.get(job.job_name)
+                if job_name_doc:
+                    job_ids = json.loads(job_name_doc)
+                    if sorted(job_ids) != sorted(set(job_ids)):
+                        LOGGER.warning("jobs-db has duplicates for %s", job.job_name)
+
+                if job.job_id not in job_ids:
+                    job_ids.append(job.job_id)
+                    job_ids = json.dumps(job_ids)
+                    await jobs_db.set(job.job_name, job_ids)
+
+                return job.job_id
+
+            except Exception as err:
+                LOGGER.error(err)
 
     async def find_job_logs(self, job_id: str) -> Optional[Dict]:
         """
@@ -414,9 +655,10 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         :return: job logs document
         """
         if job_id:
-            job_logs = await self.logs_db.get(job_id)
+            logs_db = await self.logs_db_alive
+            job_logs = await logs_db.get(job_id)
             if job_logs:
-                return job_logs
+                return json.loads(job_logs)
         LOGGER.error("FAIL to find_job_logs with job_id: %s", job_id)
 
     async def save_job_logs(self, job: AWSBatchJob) -> List[int]:
@@ -428,30 +670,22 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
         """
         # TODO: update return data type and content
         if job.job_id:
-            return await self.logs_db.set(job.job_id, job.db_logs_data)
+            logs_db = await self.logs_db_alive
+            return await logs_db.set(job.job_id, json.dumps(job.db_logs_data))
         LOGGER.error("FAIL to save_job_logs")
 
-    async def all_job_ids(self) -> Set[str]:
-        """
-        Find all jobId keys.
-        """
-        job_ids = set()
-        async for key in self.jobs_db.scan_iter():
-            if valid_uuid4(key):
-                job_ids.add(key)
-        return job_ids
-
     async def find_jobs_to_run(self) -> List[AWSBatchJob]:
         """
         Find all jobs that have not SUCCEEDED.
         """
         jobs_outstanding = []
-        async for key in self.jobs_db.scan_iter():
+        jobs_db = await self.jobs_db_alive
+        async for key in jobs_db.scan_iter():
             if valid_uuid4(key):
-                job_dict = await self.find_by_job_id(key)
+                job_dict = await self._find_by_job_id(job_id=key, jobs_db=jobs_db)
                 job = AWSBatchJob(**job_dict)
                 LOGGER.debug(
-                    "AWS Batch job (%s:%s) has db status: %s",
+                    "AWS batch-db (%s:%s) status: %s",
                     job.job_name,
                     job.job_id,
                     job.status,
@@ -496,10 +730,12 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
                 LOGGER.debug(job.job_description)
                 continue
 
+            # TODO: use a common jobs-db instance for all these
+
             db_job = await self.find_latest_job_name(job.job_name)
             if db_job:
                 LOGGER.debug(
-                    "AWS Batch job (%s:%s) has db status: %s",
+                    "AWS batch-db (%s:%s) status: %s",
                     db_job.job_name,
                     db_job.job_id,
                     db_job.status,
@@ -523,7 +759,7 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
             db_job = await self.find_latest_job_name(job.job_name)
             if db_job:
                 LOGGER.debug(
-                    "AWS Batch job (%s:%s) recovered from db with status: %s",
+                    "AWS batch-db (%s:%s) status: %s",
                     db_job.job_name,
                     db_job.job_id,
                     db_job.status,
@@ -538,7 +774,7 @@ class AioAWSBatchRedisDB(AioAWSBatchDB):
 @dataclass
 class AioAWSBatchTinyDB(AioAWSBatchDB):
     """
-    AWS Batch job databases
+    AWS Batch job databases - TinyDB implementation
 
     The jobs and logs are kept in separate DBs so
     that performance on the jobs_db is not compromised
@@ -588,8 +824,8 @@ class AioAWSBatchTinyDB(AioAWSBatchDB):
         # by too much data from job logs.
         self.jobs_db = tinydb.TinyDB(self.jobs_db_file)
         self.logs_db = tinydb.TinyDB(self.logs_db_file)
-        LOGGER.info("Using batch-jobs-db file: %s", self.jobs_db_file)
-        LOGGER.info("Using batch-logs-db file: %s", self.logs_db_file)
+        LOGGER.info("Using jobs-db file: %s", self.jobs_db_file)
+        LOGGER.info("Using logs-db file: %s", self.logs_db_file)
 
         # Lazy init for any asyncio instances
         self._db_sem = None
@@ -608,14 +844,85 @@ class AioAWSBatchTinyDB(AioAWSBatchDB):
             self._db_sem = asyncio.Semaphore()
         return self._db_sem
 
-    async def all_job_ids(self) -> Set[str]:
+    async def all_jobs(self) -> List[AWSBatchJob]:
+        """
+        Collect all jobs.
+
+        Warning: this could exceed memory, try to use
+        the :py:meth:`gen_all_jobs` wherever possible.
+        """
+        jobs = []
+        async for j in self.gen_all_jobs():
+            jobs.append(j)
+        return jobs
+
+    async def gen_all_jobs(self) -> AsyncIterator[AWSBatchJob]:
+        """
+        Generate all jobs.
+        """
         async with self.db_semaphore:
-            job_ids = set()
             for job_doc in self.jobs_db.all():
                 job_id = job_doc.get("job_id", "")
                 if valid_uuid4(job_id):
-                    job_ids.add(job_id)
-            return job_ids
+                    yield AWSBatchJob(**job_doc)
+
+    async def all_job_ids(self) -> Set[str]:
+        """
+        Collect all jobIds.
+        """
+        job_ids = set()
+        async for job_id in self.gen_job_ids():
+            job_ids.add(job_id)
+        return job_ids
+
+    async def gen_job_ids(self) -> AsyncIterator[str]:
+        """
+        Generate all jobIds.
+        """
+        async with self.db_semaphore:
+            for job_doc in self.jobs_db.all():
+                job_id = job_doc.get("job_id", "")
+                if valid_uuid4(job_id):
+                    yield job_id
+
+    async def count_by_job_status(self) -> Counter:
+        """
+        Count all jobs by jobStatus
+
+        :return: a Counter of jobs by job status (could contain multiple
+            entries for the same jobName, if it is run more than once)
+        """
+        counter = Counter()
+        for job_status in AWSBatchJobStates:
+            counter[job_status.name] = 0
+        async with self.db_semaphore:
+            for job_doc in self.jobs_db.all():
+                job = AWSBatchJob(**job_doc)
+                counter[job.status] += 1
+        return counter
+
+    async def group_by_job_status(self) -> Dict[str, List[Tuple[str, str, str]]]:
+        """
+        Group all jobId by jobStatus
+
+        :return: a dictionary of job info by job status (could contain multiple
+            entries with the same jobName if it is run multiple times);
+            the dictionary values contain a list of job information tuples, e.g.
+
+            .. code-block::
+
+                { status: [ (job.job_id, job.job_name, job.status), ] }
+
+        """
+        groups = defaultdict(list)
+        for job_status in AWSBatchJobStates:
+            groups[job_status.name] = []
+        async with self.db_semaphore:
+            for job_doc in self.jobs_db.all():
+                job = AWSBatchJob(**job_doc)
+                job_info = (job.job_id, job.job_name, job.status)
+                groups[job.status].append(job_info)
+        return groups
 
     async def find_by_job_id(self, job_id: str) -> Optional[tinydb.database.Document]:
         """
@@ -652,7 +959,7 @@ class AioAWSBatchTinyDB(AioAWSBatchDB):
         jobs_saved = await self.find_by_job_name(job_name)
         if jobs_saved:
             db_jobs = [AWSBatchJob(**job_doc) for job_doc in jobs_saved]
-            db_jobs = sorted(db_jobs, key=lambda j: j.created)
+            db_jobs = sorted(db_jobs, key=lambda j: j.created or j.submitted)
             db_job = db_jobs[-1]
             return db_job
 
@@ -768,7 +1075,7 @@ class AioAWSBatchTinyDB(AioAWSBatchDB):
         jobs_outstanding = []
         for job in jobs:
             LOGGER.info(
-                "AWS Batch job (%s:%s) has db status: %s",
+                "AWS batch-db (%s:%s) status: %s",
                 job.job_name,
                 job.job_id,
                 job.status,
@@ -817,7 +1124,7 @@ class AioAWSBatchTinyDB(AioAWSBatchDB):
             db_job = await self.find_latest_job_name(job.job_name)
             if db_job:
                 LOGGER.info(
-                    "AWS Batch job (%s:%s) has db status: %s",
+                    "AWS batch-db (%s:%s) status: %s",
                     db_job.job_name,
                     db_job.job_id,
                     db_job.status,
@@ -841,7 +1148,7 @@ class AioAWSBatchTinyDB(AioAWSBatchDB):
             db_job = await self.find_latest_job_name(job.job_name)
             if db_job:
                 LOGGER.info(
-                    "AWS Batch job (%s:%s) recovered from db with status: %s",
+                    "AWS batch-db (%s:%s) status: %s",
                     db_job.job_name,
                     db_job.job_id,
                     db_job.status,
